==> kaffe-0.8.0.tgz: kaffe-0.8.0/kaffe/kaffevm/intrp/machine.h <==
/*
 * machine.h
 *
 * Copyright (c) 1996 T. J. Wilkinson & Associates, London, UK.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * Written by Tim Wilkinson <tim@tjwassoc.demon.co.uk>
 */

#ifndef __machine_h
#define	__machine_h

#define current_class()		(meth->class)

#define getpc(n)		(code[pc+1+(n)])
#define getcode(n)		(code[(n)])
#define	putpc(n, v)		code[pc+(n)] = (v)

#define	object_array_offset	(OBJECT_DATA)
#define	object_array_length	(OBJECT_SIZE)
#define object_colour()		(OBJECT_IDX)
#define object_white()		(COLOUR_WHITE)

#define	get_method_info(idx)  getMethodSignatureClass(idx, meth, &cinfo)

#define	get_dispatch_table(mtable) \
	move_ref(mtable, ((slots*)&cinfo.class->dtable))

#define	method_name()		(cinfo.method->name)
#define	method_sig()		(cinfo.method->signature)
#define method_idx()		(cinfo.method->idx)
#define method_method()		(cinfo.method)
#define method_class()		(cinfo.class)
#define	method_nargs()		(cinfo.in)
#define	method_dtable_offset	OBJECT_DTABLE
#define	method_returntype()	(cinfo.rettype)

#define	get_field_info(_idx) \
	field = getField(_idx, false, meth, &crinfo)

#define	get_static_field_info(_idx) \
	field = getField(_idx, true, meth, &crinfo)

#define	field_data()		(OBJECT_DATA)
#define field_class()		(crinfo)
#define	field_statics()		((char*)crinfo->staticData)

#define	get_class_info(_idx) \
	crinfo = getClass(_idx, meth->class)

#define	class_object()		(crinfo)

#define	switchpair_size		8
#define	switchpair_addr		4
#define	switchtable_shift	2

struct _methods;
void virtualMachine(struct _methods*, slots*, slots*);

#endif

==> kaffe-0.8.3.tgz: kaffe-0.8.3/kaffe/kaffevm/intrp/machine.h <==
/*
 * machine.h
 *
 * Copyright (c) 1996 T. J. Wilkinson & Associates, London, UK.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * Written by Tim Wilkinson <tim@tjwassoc.demon.co.uk>
 */

#ifndef __machine_h
#define	__machine_h

#define current_class()		(meth->class)

#define getpc(n)		(code[pc+1+(n)])
#define getcode(n)		(code[(n)])
#define	putpc(n, v)		code[pc+(n)] = (v)

#define	object_array_offset	(ARRAY_DATA_OFFSET)
#define	object_array_length	(ARRAY_SIZE_OFFSET)

#define	get_method_info(idx)  getMethodSignatureClass(idx, meth, &cinfo)

#define	get_dispatch_table(mtable) \
	move_ref(mtable, ((slots*)&cinfo.class->dtable))

#define	method_name()		(cinfo.method->name)
#define	method_sig()		(cinfo.method->signature)
#define method_idx()		(cinfo.method->idx)
#define method_method()		(cinfo.method)
#define method_class()		(cinfo.class)
#define	method_nargs()		(cinfo.in)
#define	method_dtable_offset	OBJECT_DTABLE_OFFSET
#define	method_returntype()	(cinfo.rettype)

#define	get_field_info(_idx) \
	field = getField(_idx, false, meth, &crinfo)

#define	get_static_field_info(_idx) \
	field = getField(_idx, true, meth, &crinfo)

#define	field_data()		(OBJECT_DATA_OFFSET)
#define field_class()		(crinfo)
#define	field_statics()		((char*)crinfo->staticData)

#define	get_class_info(_idx) \
	crinfo = getClass(_idx, meth->class)

#define	class_object()		(crinfo)

#define	switchpair_size		8
#define	switchpair_addr		4
#define	switchtable_shift	2

struct _methods;
void virtualMachine(struct _methods*, slots*, slots*);

#endif
